==> bnd_1.50.0.orig.tar.gz: bnd-1.50.0/biz.aQute.junit/src/aQute/junit/plugin/ProjectTesterImpl.java <==
package aQute.junit.plugin;

import java.util.*;

import aQute.bnd.build.*;
import aQute.bnd.service.*;
import aQute.junit.constants.*;
import aQute.lib.osgi.*;

public class ProjectTesterImpl extends ProjectTester implements TesterConstants, EclipseJUnitTester {
	int					port	= -1;
	String				host;
	Project				project;
	String				report;
	boolean				prepared;

	public ProjectTesterImpl(Project project) throws Exception {
		super(project);
		this.project = project;
	}

	public boolean prepare() throws Exception {
		if (!prepared) {
			prepared = true;
			super.prepare();
			ProjectLauncher launcher = getProjectLauncher();
			if (port > 0) {
				launcher.getRunProperties().put(TESTER_PORT, "" + port);
				if (host != null)
					launcher.getRunProperties().put(TESTER_HOST, "" + host);

			}
			launcher.getRunProperties().put(TESTER_DIR, getReportDir().getAbsolutePath());
			launcher.getRunProperties().put(TESTER_CONTINUOUS, "" + getContinuous());
			if ( Processor.isTrue(project.getProperty(Constants.RUNTRACE)))
				launcher.getRunProperties().put(TESTER_TRACE, "true");

			Collection<String> testnames = getTests();
			if (testnames.size() > 0) {
				launcher.getRunProperties().put(TESTER_NAMES, Processor.join(testnames));
			}
			// This is only necessary because we might be picked
			// as default and that implies we're not on the -testpath
			launcher.addDefault(Constants.DEFAULT_TESTER_BSN);
			launcher.prepare();
		}
		return true;
	}

	public int test() throws Exception {
		prepare();
		return getProjectLauncher().launch();
	}

	public void setHost(String host) {
		this.host = host;
	}

	public void setPort(int port) {
		this.port = port;
	}

}

==> bnd_2.1.0.orig.tar.gz: bnd-2.1.0/biz.aQute.junit/src/aQute/junit/plugin/ProjectTesterImpl.java <==
package aQute.junit.plugin;

import java.io.*;
import java.util.*;

import aQute.bnd.build.*;
import aQute.bnd.osgi.*;
import aQute.bnd.service.*;
import aQute.junit.constants.*;

public class ProjectTesterImpl extends ProjectTester implements TesterConstants, EclipseJUnitTester {
	int		port	= -1;
	String	host;
	Project	project;
	boolean	prepared;

	public ProjectTesterImpl(Project project) throws Exception {
		super(project);
		this.project = project;
	}

	@Override
	public boolean prepare() throws Exception {
		if (!prepared) {
			prepared = true;
			super.prepare();
			ProjectLauncher launcher = getProjectLauncher();
			if (port > 0) {
				launcher.getRunProperties().put(TESTER_PORT, "" + port);
				if (host != null)
					launcher.getRunProperties().put(TESTER_HOST, "" + host);

			}
			launcher.getRunProperties().put(TESTER_DIR, getReportDir().getAbsolutePath());
			launcher.getRunProperties().put(TESTER_CONTINUOUS, "" + getContinuous());
			if (Processor.isTrue(project.getProperty(Constants.RUNTRACE)))
				launcher.getRunProperties().put(TESTER_TRACE, "true");
			
			try {
				// use reflection to avoid NoSuchMethodError due to change in API
				File cwd = (File) getClass().getMethod("getCwd").invoke(this);
				if (cwd != null) launcher.setCwd(cwd);
			} catch (NoSuchMethodException e){
				// ignore
			}

			Collection<String> testnames = getTests();
			if (testnames.size() > 0) {
				launcher.getRunProperties().put(TESTER_NAMES, Processor.join(testnames));
			}
			// This is only necessary because we might be picked
			// as default and that implies we're not on the -testpath
			launcher.addDefault(Constants.DEFAULT_TESTER_BSN);
			launcher.prepare();
		}
		return true;
	}

	@Override
	public int test() throws Exception {
		prepare();
		return getProjectLauncher().launch();
	}

	public void setHost(String host) {
		this.host = host;
	}

	public void setPort(int port) {
		this.port = port;
	}

}
